#!/usr/bin/python3

APP_ID = "org.gnome.World.Iotas"
GETTEXT_PACKAGE = "iotas"
LOCALEDIR = "/usr/share/locale"
NAME = "Iotas"
PKGDATADIR = "/usr/share/iotas"
PROFILE = ""
VERSION = "2026.7"

IS_DEVEL = PROFILE == "Devel"
SUFFIX = " (Devel)" if IS_DEVEL else ""
SHORT_NAME = GETTEXT_PACKAGE

APP_ID_CHANGE_VERSION = "0.2.7"
